@@ -8,19 +8,19 @@ class DirectoryAdapter:
     def __init__(self, dir_path: Path):
         self.dir_path = dir_path
 
-    def create(self) -> None:
+    def create_dir(self) -> None:
         filesystem.create_dir(self.dir_path)
 
-    def delete(self) -> None:
+    def delete_dir(self) -> None:
         filesystem.delete_dir(self.dir_path)
 
     def delete_file(self, filename: str) -> None:
         filesystem.delete_file(self.dir_path / filename)
 
-    def search(self, filename: str = "*") -> List[Path]:
-        return filesystem.search_files(self.dir_path / "**" / filename)
+    def search(self, filename_regex: str = "*") -> List[Path]:
+        return filesystem.search_files(self.dir_path / "**" / filename_regex)
 
-    def exists(self) -> bool:
+    def dir_exists(self) -> bool:
         return filesystem.exists(self.dir_path)
 
     def file_exists(self, filename: str) -> bool:
@@ -29,11 +29,11 @@ class DirectoryAdapter:
     def read_file(self, filename: str) -> str:
         return filesystem.read_file(self.dir_path / filename)
 
-    def write_file(self, filename: str, data: str = "") -> None:
+    def save_file(self, filename: str, data: str = "") -> None:
         filesystem.write_file(self.dir_path / filename, data)
 
-    def read_json(self, filename: str, **kwargs: Any) -> dict:
-        return filesystem.read_json(self.dir_path / filename, **kwargs)
+    def read_json_file(self, filename: str, **kwargs: Any) -> dict:
+        return filesystem.read_json_file(self.dir_path / filename, **kwargs)
 
-    def write_json(self, filename: str, data: dict, **kwargs: Any) -> None:
-        filesystem.write_json(self.dir_path / filename, data, **kwargs)
+    def save_json_file(self, filename: str, data: dict, **kwargs: Any) -> None:
+        filesystem.write_json_file(self.dir_path / filename, data, **kwargs)
