@@ -20,14 +20,14 @@ class FileAdapter:
     def exists(self) -> bool:
         return filesystem.exists(self.file_path)
 
-    def read_file(self) -> str:
+    def read(self) -> str:
         return filesystem.read_file(self.file_path)
 
-    def write_file(self, data: str = "") -> None:
+    def save(self, data: str = "") -> None:
         filesystem.write_file(self.file_path, data)
 
     def read_json(self, **kwargs: Any) -> dict:
-        return filesystem.read_json(self.file_path, **kwargs)
+        return filesystem.read_json_file(self.file_path, **kwargs)
 
-    def write_json(self, data: dict, **kwargs: Any) -> None:
-        filesystem.write_json(self.file_path, data, **kwargs)
+    def save_json(self, data: dict, **kwargs: Any) -> None:
+        filesystem.write_json_file(self.file_path, data, **kwargs)
