@@ -38,11 +38,11 @@ def write_file(file_path: Path, data: str = "") -> None:
         file.write(data)
 
 
-def read_json(file_path: Path, **kwargs: Any) -> dict:
+def read_json_file(file_path: Path, **kwargs: Any) -> dict:
     with open(file_path) as file:
         return load(file, **kwargs)
 
 
-def write_json(file_path: Path, data: dict, indent=2, **kwargs: Any) -> None:
+def write_json_file(file_path: Path, data: dict, indent=2, **kwargs: Any) -> None:
     with open(file_path, "w") as file:
         dump(data, file, indent=indent, **kwargs)
